/* Calculate average frames per second.
   Copyright (C) 2006 Carl Fredrik Hammar (hammy.lite@gmail.com)

   This file is part of GP2X Sand.

   GP2X Sand is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   GP2X Sand is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details. 

   You should have received a copy of the GNU General Public License along
   with GP2X Sand; if not, write to the Free Software Foundation, Inc., 51
   Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA */

#ifndef FPSCOUNTER_H
#define FPSCOUNTER_H

/* This module is used to calculate the average fps over the last n
   frames.  Where n is an appropriate number that give an accurate
   average, which is private to this module.  Using it is simply a matter
   of giving it the current time after each frame is displayed. */

/* Initialize the fps counter. TIMESTAMP should be the current time in
   milliseconds. */
void
fps_counter_init (int timestamp);

/* Stores the latest frames timestamp for later use to calculate the
   average.  TIMESTAMP should be the time in milliseconds when the frame
   was finished.  Call this function directly after each frame is
   displayed.  If TIMESTAMP is lower than the last timestamp pushed then
   this call will be ignored. */
void
fps_counter_frame_timestamp_push (int timestamp);

/* Calculate the average fps and return it. */
int
fps_counter_framerate_get ();

#endif /* not FPSCOUNTER_H */
