/* Arithmetic on vectors with signed integer coordinates.
   Copyright (C) 2006 Carl Fredrik Hammar (hammy.lite@gmail.com)

   This file is part of GP2X Sand.

   GP2X Sand is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.

   GP2X Sand is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
   General Public License for more details. 

   You should have received a copy of the GNU General Public License along
   with GP2X Sand; if not, write to the Free Software Foundation, Inc., 51
   Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA */

#ifndef VMATH_H
#define VMATH_H

#include <stdint.h>
#include <stdbool.h>

#ifndef INLINE
#define INLINE extern inline
#endif

struct vect_str
{
  int x;
  int y;
};

typedef struct vect_str vect_t;

INLINE
vect_t
vcons (int16_t x, int16_t y)
{
  vect_t u = { x, y };
  return u;
}

INLINE
int16_t
vcoord_x (vect_t u)
{
  return u.x;
}

INLINE
int16_t
vcoord_y (vect_t u)
{
  return u.y;
}

INLINE
vect_t
vneg (vect_t u)
{
  vect_t v = { -u.x, -u.y };
  return v;
}

INLINE
vect_t
vadd (vect_t u, vect_t v)
{
  vect_t w = { u.x + v.x, u.y + v.y };
  return w;
}

INLINE
vect_t
vsub (vect_t u, vect_t v)
{
  vect_t w = { u.x - v.x, u.y - v.y };
  return w;
}

INLINE
vect_t
vadds (vect_t u, int16_t s)
{
  vect_t v = { u.x + s, u.y + s };
  return v;
}

INLINE
vect_t
vsubs (vect_t u, int16_t s)
{
  vect_t v = { u.x - s, u.y - s };
  return v;
}

INLINE
vect_t
vmuls (vect_t u, int16_t s)
{
  vect_t v = { u.x * s, u.y * s };
  return v;
}

INLINE
vect_t
vdivs (vect_t u, int16_t s)
{
  vect_t v = { u.x / s, u.y / s };
  return v;
}

INLINE
bool
veql (vect_t u, vect_t v)
{
  return u.x == v.x && u.y == v.y;
}

#endif /* not VMATH_H */
